# Commitizen CLI (breve-flavoured)

A [Commitizen CLI](https://commitizen-tools.github.io/commitizen/) templated flavored with the brevetech team touch.

## Features
- Internationalization (EN/ES)
- Gitmoji
- Semantic Versioning
- Commit validation (with or without gitmoji)